You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pinot.apache.org by si...@apache.org on 2022/06/30 01:12:59 UTC

[pinot] branch master updated: Refactor input manager of recommender (#8988)

This is an automated email from the ASF dual-hosted git repository.

siddteotia pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/pinot.git


The following commit(s) were added to refs/heads/master by this push:
     new 37992b98ce Refactor input manager of recommender (#8988)
37992b98ce is described below

commit 37992b98ce5770de5af6bdb9eac936903cc22bea
Author: Jia Guo <ji...@linkedin.com>
AuthorDate: Wed Jun 29 18:12:54 2022 -0700

    Refactor input manager of recommender (#8988)
    
    * Refactor input manager of recommender
    
    * Trigger Test
---
 .../pinot/controller/recommender/io/InputManager.java       | 13 ++++++-------
 1 file changed, 6 insertions(+), 7 deletions(-)

diff --git a/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/io/InputManager.java b/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/io/InputManager.java
index 02aca45911..4436fc356c 100644
--- a/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/io/InputManager.java
+++ b/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/io/InputManager.java
@@ -224,14 +224,13 @@ public class InputManager {
     Set<String> jsonIndexColumns = _overWrittenConfigs.getIndexConfig().getJsonIndexColumns();
     Set<String> noDictionaryColumns = _overWrittenConfigs.getIndexConfig().getNoDictionaryColumns();
 
-    /*Validate if there's conflict between NoDictionaryColumns and dimNamesWithAnyIndex*/
-    Set<String> dimNamesWithAnyIndex = new HashSet<>();
-    dimNamesWithAnyIndex.add(sortedColumn);
-    dimNamesWithAnyIndex.addAll(invertedIndexColumns);
-    dimNamesWithAnyIndex.addAll(rangeIndexColumns);
-    dimNamesWithAnyIndex.addAll(jsonIndexColumns);
+    /*Validate if there's conflict between NoDictionaryColumns and dimNamesWithDictionaryDependentIndex*/
+    Set<String> dimNamesWithDictionaryDependentIndex = new HashSet<>();
+    dimNamesWithDictionaryDependentIndex.add(sortedColumn);
+    dimNamesWithDictionaryDependentIndex.addAll(invertedIndexColumns);
+    dimNamesWithDictionaryDependentIndex.addAll(rangeIndexColumns);
     for (String colName : noDictionaryColumns) {
-      if (dimNamesWithAnyIndex.contains(colName)) {
+      if (dimNamesWithDictionaryDependentIndex.contains(colName)) {
         throw new InvalidInputException(
             "Column {0} presents in both overwritten indices and overwritten no dictionary columns", colName);
       }


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@pinot.apache.org
For additional commands, e-mail: commits-help@pinot.apache.org